package WebService::Steam;

use strict;
use warnings;

our $VERSION = 0.2;

1;

__END__
 
=head1 NAME

WebService::Steam - An OO Perl interface to the Steam community data

=head1 MODULES AND UTILITIES

=head2 WebService::Steam::Group

=head2 WebService::Steam::User
